Post
Because our cache gets wasted on optimizing the lookup for "send", we have to rely on a second tier cache lookup for the actual method we want to call, "my_method". This lookup is still reasonably fast for most programs, but as we saw earlier, it's around 1.5x slower than the direct call. /7
0 reposts1 like
Not just technically or in theory, all 3 are in fact equivalently fast on TruffleRuby! bsky.app/profile/ereg...
Though with @truffleruby.bsky.social one can in fact just #send it, even publicly, at 276 million iterations/second in all 3 cases! gist.github.com/byroot/780c1... (using the benchmark from bsky.app/profile/byro...)